#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.6.0
visibility:           public
id:                   persistent-2.14.6.0-3kQR514rtT0CT79v4LQQXd
key:                  persistent-2.14.6.0-3kQR514rtT0CT79v4LQQXd
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  dc06f4f7020bb6d0bef8ebbdfd21c52a
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-2.14.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-2.14.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-2.14.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.6.0-3kQR514rtT0CT79v4LQQXd
depends:
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o
    attoparsec-0.14.4-JfqiEkfNFnE8n0O4G6WZl6
    attoparsec-aeson-2.2.0.1-If65CUgsRZrFq45Cy1aiAZ base-4.18.2.1
    base64-bytestring-1.2.1.0-HSSC8ZpQ1EiHU6Qv1r7ZrY
    blaze-html-0.9.2.0-EgbbWPmo3205UQl3AObEBN bytestring-0.11.5.3
    conduit-1.3.6.1-GLye9k05ayiLdzpPDhJU0K containers-0.6.7
    deepseq-1.4.8.1 fast-logger-3.2.4-GgJm2dWX2nY3H5zEqRvwad
    http-api-data-0.6.1-B4xD2REm6ADDTbBWwdbcen
    lift-type-0.1.2.0-Fw2ewlYocgz4tKrZppmhnp
    monad-logger-0.3.42-CtEWXmRQcRS9Y13lEQuG7v mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    resource-pool-0.2.3.2-2qcyE7yWvbp31kkuD5Uzjj
    resourcet-1.2.6-2ZRVpZAaCnB5eaGpQGOamD
    scientific-0.3.8.1-3SFYxv3bn8iY0w5N4dHFv
    silently-1.2.5.4-BeJQMFrht8zIosElyGUCP7 template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-GRB2PbZNXtTdghze3r0Fl
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-8EuOvwMQbnH3C5Rgo2gyOI
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp
    vault-0.3.1.6-DBdbo6YM08YBBhh2vxlC07
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

